---
title: '[공지] 인증결제 오류 조치 완료 공지'
category: 공지사항
tags:
  - 공통
  - 공지사항
datetime: 2023-07-13T15:00:00.000Z
---

안녕하세요,

포트원 고객지원팀입니다.

금일 (2023-07-14) 결제창 방식의 인증결제를 이용하시는 경우

결제창이 호출되지 않고 오류가 발생되는 이슈가 있어 긴급 확인 후 조치 완료 되었음을 안내드립니다.

자세한 사항은 아래 상세 내용을 참고 부탁드리겠습니다.

### **상세**

- 이슈 발생시각 : 2023년 07월 14일 19:00\~19:32  (28분) - 조치완료
  - 2023년 07월 14일 19:04 : 인증결제창 호출 불가 상태 시작
  - 2022년 07월 14일 19:05 : PortOne 장애 인지
  - 2023년 07월 14일 19:06 : 서버 증설 작업 시작(평소 대비 2배 자원 할당)
  - 2023년 07월 14일 19:32 : 서비스 정상화

* 현상 : (결제창을 띄우는 방식의 인증결제) 결제창 호출시 오류 발생

- 발생 원인 :  인증결제 요청 트래픽이 평소 대비 5배 이상 급등 하면서 해당 트래픽을 PortOne 서버가 처리하지 못하여 결제 이슈 발생.

* 재발방지 안
  - 일시적으로 비 활성화되어있던 오토스케일링 2023년 7월 14일 재 활성화 완료
  - 서버의 평상시 리소스를 평균 트래픽 대비 최소 3.5배수 이상 유휴 리소스 증설

서비스 이용에 불편을 드려 너무나도 죄송합니다.

앞으로 더욱더 서비스 안정성을 위해 최선을 다해 노력하는 포트원(PortOne)이 되겠습니다.

감사합니다.
